# OGC

ogc - provisioning, that's it.

# Get started

- [Getting Started Guide](https://adam-stokes.github.io/ogc/)
- User Guide
  -  [Managing Deployment](https://adam-stokes.github.io/ogc/user-guide/managing-nodes/)
  -  [Defining Layouts](https://adam-stokes.github.io/ogc/user-guide/defining-layouts/)
  -  [Scripting](https://adam-stokes.github.io/ogc/user-guide/scripting/)
# License

MIT.


